@@ -31,11 +31,7 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-#include <libdbusmenu-gtk3/menu.h>
-#else
 #include <libdbusmenu-gtk/menu.h>
-#endif
 
 #include <libindicator/indicator.h>
 #include <libindicator/indicator-object.h>
@@ -118,8 +114,8 @@ indicator_session_class_init (IndicatorSessionClass *klass)
 	object_class->finalize = indicator_session_finalize;
 
 	IndicatorObjectClass * io_class = INDICATOR_OBJECT_CLASS(klass);
-  io_class->get_entries = indicator_session_get_entries;
-  io_class->get_location = indicator_session_get_location;
+	io_class->get_entries = indicator_session_get_entries;
+	io_class->get_location = indicator_session_get_location;
 	return;
 }
 
@@ -140,6 +136,7 @@ indicator_session_init (IndicatorSession *self)
 
   GtkWidget* avatar_icon = NULL;
   // users
+  self->users.name_hint = PACKAGE"-users";
   self->users.menu =  GTK_MENU (dbusmenu_gtkmenu_new (INDICATOR_USERS_DBUS_NAME,
                                                       INDICATOR_USERS_DBUS_OBJECT));
   // Set the image to the default avator image
@@ -165,11 +162,15 @@ indicator_session_init (IndicatorSession *self)
   }
                                                       
   self->users.label = GTK_LABEL (gtk_label_new (NULL));
+  self->users.accessible_desc = _("User Menu");
 
   const gchar *greeter_var;
   greeter_var = g_getenv("INDICATOR_GREETER_MODE");
   greeter_mode = g_strcmp0(greeter_var, "1") == 0;
+
   // devices
+  self->devices.name_hint = PACKAGE"-devices";
+  self->devices.accessible_desc = _("Device Menu");
   self->devices.menu = GTK_MENU (dbusmenu_gtkmenu_new(INDICATOR_SESSION_DBUS_NAME,
                                                       INDICATOR_SESSION_DBUS_OBJECT));
   if (greeter_mode){
@@ -277,10 +278,10 @@ indicator_session_get_location (IndicatorObject * io,
 {  
 	IndicatorSession * self = INDICATOR_SESSION (io);
   if (entry == &self->users){
-    return 1;
+    return 0;
   }
   else if (entry == &self->devices){
-    return 0;
+    return 1;
   }
   g_warning ("IOEntry handed to us to position but we don't own it!");
   return 0;
@@ -427,7 +428,7 @@ user_real_name_get_cb (GObject * obj, GAsyncResult * res, gpointer user_data)
 	}
   
   const gchar* username = NULL;
-  g_variant_get (result, "(s)", &username);
+  g_variant_get (result, "(&s)", &username);
   indicator_session_update_users_label (self, username);
 	return;
 }
@@ -480,7 +481,7 @@ receive_signal (GDBusProxy * proxy,
 
 	if (g_strcmp0(signal_name, "UserRealNameUpdated") == 0) {
     const gchar* username = NULL;
-    g_variant_get (parameters, "(s)", &username);
+    g_variant_get (parameters, "(&s)", &username);
     indicator_session_update_users_label (self, username);	
   }
   else if (g_strcmp0(signal_name, "UserMenuIsVisible") == 0) {
@@ -515,6 +516,8 @@ receive_signal (GDBusProxy * proxy,
       g_debug ("reboot required");
       indicator_image_helper_update(self->devices.image, ICON_RESTART);
     }
+    self->devices.accessible_desc = _("Device Menu (reboot required)");
+    g_signal_emit(G_OBJECT(self), INDICATOR_OBJECT_SIGNAL_ACCESSIBLE_DESC_UPDATE_ID, 0, &(self->devices));
   }  
 }
 
@@ -710,14 +713,8 @@ indicator_session_update_users_label (IndicatorSession* self,
   }  
 
   GSettings* settings = g_settings_new ("com.canonical.indicator.session");
-  gboolean use_name = g_settings_get_boolean (settings,
-                                              "show-real-name-on-panel");    
+  const gboolean use_name = g_settings_get_boolean (settings, "show-real-name-on-panel");    
+  gtk_label_set_text (self->users.label, name);
+  gtk_widget_set_visible (GTK_WIDGET(self->users.label), use_name);
   g_object_unref (settings);
-  gtk_label_set_text (self->users.label, g_strdup(name));
-  if (use_name){ 
-    gtk_widget_show(GTK_WIDGET(self->users.label));
-  }
-  else{
-    gtk_widget_hide(GTK_WIDGET(self->users.label));
-  }
 }
