@@ -24,9 +24,6 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <libdbusmenu-glib/menuitem.h>
 
-void screensaver_throttle (gchar * reason);
-void screensaver_unthrottle (void);
-
 gboolean will_lock_screen (void);
 void lock_screen (DbusmenuMenuitem * mi, guint timestamp, gpointer data);
 gboolean lock_screen_setup (gpointer data);
