@@ -26,6 +26,7 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
 
 #include <unistd.h>
+#include <locale.h>
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
@@ -39,11 +40,7 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <libdbusmenu-glib/client.h>
 
 #include <gtk/gtk.h>
-#if GTK_CHECK_VERSION(3, 0, 0)
-#include <libdbusmenu-gtk3/menuitem.h>
-#else
 #include <libdbusmenu-gtk/menuitem.h>
-#endif
 
 #include <libindicator/indicator-service.h>
 
